// Copyright 2023 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// GENERATED FROM THE API DEFINITION IN
//   extensions/common/api/printer_provider.idl
// by tools/json_schema_compiler.
// DO NOT EDIT.

#include "extensions/common/api/printer_provider.h"

#include <memory>
#include <ostream>
#include <string>
#include <utility>
#include <vector>

#include "base/check.h"
#include "base/check_op.h"
#include "base/notreached.h"
#include "base/strings/string_number_conversions.h"
#include "base/strings/utf_string_conversions.h"
#include "base/values.h"
#include "tools/json_schema_compiler/util.h"
#include "extensions/common/api/usb.h"


using base::UTF8ToUTF16;

namespace extensions {
namespace api {
namespace printer_provider {
//
// Types
//

const char* ToString(PrintError enum_param) {
  switch (enum_param) {
    case PRINT_ERROR_OK:
      return "OK";
    case PRINT_ERROR_FAILED:
      return "FAILED";
    case PRINT_ERROR_INVALID_TICKET:
      return "INVALID_TICKET";
    case PRINT_ERROR_INVALID_DATA:
      return "INVALID_DATA";
    case PRINT_ERROR_NONE:
      return "";
  }
  NOTREACHED();
  return "";
}

PrintError ParsePrintError(const std::string& enum_string) {
  if (enum_string == "OK")
    return PRINT_ERROR_OK;
  if (enum_string == "FAILED")
    return PRINT_ERROR_FAILED;
  if (enum_string == "INVALID_TICKET")
    return PRINT_ERROR_INVALID_TICKET;
  if (enum_string == "INVALID_DATA")
    return PRINT_ERROR_INVALID_DATA;
  return PRINT_ERROR_NONE;
}


PrinterInfo::PrinterInfo()
 {}

PrinterInfo::~PrinterInfo() = default;
PrinterInfo::PrinterInfo(PrinterInfo&& rhs) = default;
PrinterInfo& PrinterInfo::operator=(PrinterInfo&& rhs) = default;
// static
bool PrinterInfo::Populate(
    const base::Value& value, PrinterInfo* out) {
  if (!value.is_dict()) {
    return false;
  }
  const base::Value::Dict& dict = value.GetDict();
  const base::Value* id_value = dict.Find("id");
  if (!id_value) {
    return false;
  }
  {
    auto* temp = (*id_value).GetIfString();
    if (!temp) {
      return false;
    }
    out->id = *temp;
  }

  const base::Value* name_value = dict.Find("name");
  if (!name_value) {
    return false;
  }
  {
    auto* temp = (*name_value).GetIfString();
    if (!temp) {
      return false;
    }
    out->name = *temp;
  }

  const base::Value* description_value = dict.Find("description");
  if (description_value) {
    {
      auto* temp = (*description_value).GetIfString();
      if (!temp) {
        out->description = absl::nullopt;
        return false;
      }
      out->description = *temp;
    }
  }

  return true;
}

// static
std::unique_ptr<PrinterInfo> PrinterInfo::FromValue(const base::Value& value) {
  auto out = std::make_unique<PrinterInfo>();
  bool result = Populate(value, out.get());
  if (!result)
    return nullptr;
  return out;
}

base::Value::Dict PrinterInfo::ToValue() const {
  base::Value::Dict to_value_result;

  to_value_result.Set("id", this->id);

  to_value_result.Set("name", this->name);

  if (this->description) {
    to_value_result.Set("description", *this->description);

  }

  return to_value_result;
}


PrintJob::Ticket::Ticket()
 {}

PrintJob::Ticket::~Ticket() = default;
PrintJob::Ticket::Ticket(Ticket&& rhs) = default;
PrintJob::Ticket& PrintJob::Ticket::operator=(Ticket&& rhs) = default;
// static
bool PrintJob::Ticket::Populate(
    const base::Value& value, Ticket* out) {
  if (!value.is_dict()) {
    return false;
  }
  const base::Value::Dict& dict = value.GetDict();
  out->additional_properties.Merge(dict.Clone());
  return true;
}

base::Value::Dict PrintJob::Ticket::ToValue() const {
  base::Value::Dict to_value_result;

  to_value_result.Merge(additional_properties.Clone());

  return to_value_result;
}


PrintJob::Document::Document()
 {}

PrintJob::Document::~Document() = default;
PrintJob::Document::Document(Document&& rhs) = default;
PrintJob::Document& PrintJob::Document::operator=(Document&& rhs) = default;
// static
bool PrintJob::Document::Populate(
    const base::Value& value, Document* out) {
  if (!value.is_dict()) {
    return false;
  }
  const base::Value::Dict& dict = value.GetDict();
  out->additional_properties.Merge(dict.Clone());
  return true;
}

base::Value::Dict PrintJob::Document::ToValue() const {
  base::Value::Dict to_value_result;

  to_value_result.Merge(additional_properties.Clone());

  return to_value_result;
}



PrintJob::PrintJob()
 {}

PrintJob::~PrintJob() = default;
PrintJob::PrintJob(PrintJob&& rhs) = default;
PrintJob& PrintJob::operator=(PrintJob&& rhs) = default;
// static
bool PrintJob::Populate(
    const base::Value& value, PrintJob* out) {
  if (!value.is_dict()) {
    return false;
  }
  const base::Value::Dict& dict = value.GetDict();
  const base::Value* printer_id_value = dict.Find("printerId");
  if (!printer_id_value) {
    return false;
  }
  {
    auto* temp = (*printer_id_value).GetIfString();
    if (!temp) {
      return false;
    }
    out->printer_id = *temp;
  }

  const base::Value* title_value = dict.Find("title");
  if (!title_value) {
    return false;
  }
  {
    auto* temp = (*title_value).GetIfString();
    if (!temp) {
      return false;
    }
    out->title = *temp;
  }

  const base::Value* ticket_value = dict.Find("ticket");
  if (!ticket_value) {
    return false;
  }
  {
    if (!(*ticket_value).is_dict()) {
      return false;
    }
    if (!Ticket::Populate((*ticket_value), &out->ticket)) {
      return false;
    }
  }

  const base::Value* content_type_value = dict.Find("contentType");
  if (!content_type_value) {
    return false;
  }
  {
    auto* temp = (*content_type_value).GetIfString();
    if (!temp) {
      return false;
    }
    out->content_type = *temp;
  }

  const base::Value* document_value = dict.Find("document");
  if (!document_value) {
    return false;
  }
  {
    if (!(*document_value).is_dict()) {
      return false;
    }
    if (!Document::Populate((*document_value), &out->document)) {
      return false;
    }
  }

  return true;
}

// static
std::unique_ptr<PrintJob> PrintJob::FromValue(const base::Value& value) {
  auto out = std::make_unique<PrintJob>();
  bool result = Populate(value, out.get());
  if (!result)
    return nullptr;
  return out;
}

base::Value::Dict PrintJob::ToValue() const {
  base::Value::Dict to_value_result;

  to_value_result.Set("printerId", this->printer_id);

  to_value_result.Set("title", this->title);

  to_value_result.Set("ticket", (this->ticket).ToValue());

  to_value_result.Set("contentType", this->content_type);

  to_value_result.Set("document", (this->document).ToValue());


  return to_value_result;
}



//
// Events
//

namespace OnGetPrintersRequested {

const char kEventName[] = "printerProvider.onGetPrintersRequested";

base::Value::List Create() {
  base::Value::List create_results;

  return create_results;
}

}  // namespace OnGetPrintersRequested

namespace OnGetUsbPrinterInfoRequested {

const char kEventName[] = "printerProvider.onGetUsbPrinterInfoRequested";

base::Value::List Create(const extensions::api::usb::Device& device) {
  base::Value::List create_results;
  create_results.reserve(1);
  create_results.Append((device).ToValue());

  return create_results;
}

}  // namespace OnGetUsbPrinterInfoRequested

namespace OnGetCapabilityRequested {

const char kEventName[] = "printerProvider.onGetCapabilityRequested";

base::Value::List Create(const std::string& printer_id) {
  base::Value::List create_results;
  create_results.reserve(1);
  create_results.Append(printer_id);

  return create_results;
}

}  // namespace OnGetCapabilityRequested

namespace OnPrintRequested {

const char kEventName[] = "printerProvider.onPrintRequested";

base::Value::List Create(const PrintJob& print_job) {
  base::Value::List create_results;
  create_results.reserve(1);
  create_results.Append((print_job).ToValue());

  return create_results;
}

}  // namespace OnPrintRequested

}  // namespace printer_provider
}  // namespace api
}  // namespace extensions

