// Copyright 2023 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// GENERATED FROM THE API DEFINITION IN
//   extensions/common/api/system_storage.idl
// by tools/json_schema_compiler.
// DO NOT EDIT.

#include "extensions/common/api/system_storage.h"

#include <memory>
#include <ostream>
#include <string>
#include <utility>
#include <vector>

#include "base/check.h"
#include "base/check_op.h"
#include "base/notreached.h"
#include "base/strings/string_number_conversions.h"
#include "base/strings/utf_string_conversions.h"
#include "base/values.h"
#include "tools/json_schema_compiler/util.h"

using base::UTF8ToUTF16;

namespace extensions {
namespace api {
namespace system_storage {
//
// Types
//

const char* ToString(StorageUnitType enum_param) {
  switch (enum_param) {
    case STORAGE_UNIT_TYPE_FIXED:
      return "fixed";
    case STORAGE_UNIT_TYPE_REMOVABLE:
      return "removable";
    case STORAGE_UNIT_TYPE_UNKNOWN:
      return "unknown";
    case STORAGE_UNIT_TYPE_NONE:
      return "";
  }
  NOTREACHED();
  return "";
}

StorageUnitType ParseStorageUnitType(const std::string& enum_string) {
  if (enum_string == "fixed")
    return STORAGE_UNIT_TYPE_FIXED;
  if (enum_string == "removable")
    return STORAGE_UNIT_TYPE_REMOVABLE;
  if (enum_string == "unknown")
    return STORAGE_UNIT_TYPE_UNKNOWN;
  return STORAGE_UNIT_TYPE_NONE;
}


StorageUnitInfo::StorageUnitInfo()
: type(STORAGE_UNIT_TYPE_NONE),
capacity(0.0) {}

StorageUnitInfo::~StorageUnitInfo() = default;
StorageUnitInfo::StorageUnitInfo(StorageUnitInfo&& rhs) = default;
StorageUnitInfo& StorageUnitInfo::operator=(StorageUnitInfo&& rhs) = default;
// static
bool StorageUnitInfo::Populate(
    const base::Value& value, StorageUnitInfo* out) {
  if (!value.is_dict()) {
    return false;
  }
  const base::Value::Dict& dict = value.GetDict();
  const base::Value* id_value = dict.Find("id");
  if (!id_value) {
    return false;
  }
  {
    auto* temp = (*id_value).GetIfString();
    if (!temp) {
      return false;
    }
    out->id = *temp;
  }

  const base::Value* name_value = dict.Find("name");
  if (!name_value) {
    return false;
  }
  {
    auto* temp = (*name_value).GetIfString();
    if (!temp) {
      return false;
    }
    out->name = *temp;
  }

  const base::Value* type_value = dict.Find("type");
  if (!type_value) {
    return false;
  }
  {
    const std::string* storage_unit_type_as_string = (*type_value).GetIfString();
    if (!storage_unit_type_as_string) {
      return false;
    }
    out->type = ParseStorageUnitType(*storage_unit_type_as_string);
    if (out->type == STORAGE_UNIT_TYPE_NONE) {
      return false;
    }
  }

  const base::Value* capacity_value = dict.Find("capacity");
  if (!capacity_value) {
    return false;
  }
  {
    auto temp = (*capacity_value).GetIfDouble();
    if (!temp.has_value()) {
      return false;
    }
    out->capacity = *temp;
  }

  return true;
}

// static
std::unique_ptr<StorageUnitInfo> StorageUnitInfo::FromValue(const base::Value& value) {
  auto out = std::make_unique<StorageUnitInfo>();
  bool result = Populate(value, out.get());
  if (!result)
    return nullptr;
  return out;
}

base::Value::Dict StorageUnitInfo::ToValue() const {
  base::Value::Dict to_value_result;

  to_value_result.Set("id", this->id);

  to_value_result.Set("name", this->name);

  to_value_result.Set("type", system_storage::ToString(this->type));

  to_value_result.Set("capacity", this->capacity);


  return to_value_result;
}


StorageAvailableCapacityInfo::StorageAvailableCapacityInfo()
: available_capacity(0.0) {}

StorageAvailableCapacityInfo::~StorageAvailableCapacityInfo() = default;
StorageAvailableCapacityInfo::StorageAvailableCapacityInfo(StorageAvailableCapacityInfo&& rhs) = default;
StorageAvailableCapacityInfo& StorageAvailableCapacityInfo::operator=(StorageAvailableCapacityInfo&& rhs) = default;
// static
bool StorageAvailableCapacityInfo::Populate(
    const base::Value& value, StorageAvailableCapacityInfo* out) {
  if (!value.is_dict()) {
    return false;
  }
  const base::Value::Dict& dict = value.GetDict();
  const base::Value* id_value = dict.Find("id");
  if (!id_value) {
    return false;
  }
  {
    auto* temp = (*id_value).GetIfString();
    if (!temp) {
      return false;
    }
    out->id = *temp;
  }

  const base::Value* available_capacity_value = dict.Find("availableCapacity");
  if (!available_capacity_value) {
    return false;
  }
  {
    auto temp = (*available_capacity_value).GetIfDouble();
    if (!temp.has_value()) {
      return false;
    }
    out->available_capacity = *temp;
  }

  return true;
}

// static
std::unique_ptr<StorageAvailableCapacityInfo> StorageAvailableCapacityInfo::FromValue(const base::Value& value) {
  auto out = std::make_unique<StorageAvailableCapacityInfo>();
  bool result = Populate(value, out.get());
  if (!result)
    return nullptr;
  return out;
}

base::Value::Dict StorageAvailableCapacityInfo::ToValue() const {
  base::Value::Dict to_value_result;

  to_value_result.Set("id", this->id);

  to_value_result.Set("availableCapacity", this->available_capacity);


  return to_value_result;
}


const char* ToString(EjectDeviceResultCode enum_param) {
  switch (enum_param) {
    case EJECT_DEVICE_RESULT_CODE_SUCCESS:
      return "success";
    case EJECT_DEVICE_RESULT_CODE_IN_USE:
      return "in_use";
    case EJECT_DEVICE_RESULT_CODE_NO_SUCH_DEVICE:
      return "no_such_device";
    case EJECT_DEVICE_RESULT_CODE_FAILURE:
      return "failure";
    case EJECT_DEVICE_RESULT_CODE_NONE:
      return "";
  }
  NOTREACHED();
  return "";
}

EjectDeviceResultCode ParseEjectDeviceResultCode(const std::string& enum_string) {
  if (enum_string == "success")
    return EJECT_DEVICE_RESULT_CODE_SUCCESS;
  if (enum_string == "in_use")
    return EJECT_DEVICE_RESULT_CODE_IN_USE;
  if (enum_string == "no_such_device")
    return EJECT_DEVICE_RESULT_CODE_NO_SUCH_DEVICE;
  if (enum_string == "failure")
    return EJECT_DEVICE_RESULT_CODE_FAILURE;
  return EJECT_DEVICE_RESULT_CODE_NONE;
}



//
// Functions
//

namespace GetInfo {

base::Value::List Results::Create(const std::vector<StorageUnitInfo>& info) {
  base::Value::List create_results;
  create_results.reserve(1);
  create_results.Append(json_schema_compiler::util::CreateValueFromArray(info));

  return create_results;
}
}  // namespace GetInfo

namespace EjectDevice {

Params::Params() = default;
Params::~Params() = default;

// static
std::unique_ptr<Params> Params::Create(const base::Value::List& args) {
  if (args.size() != 1) {
    return nullptr;
  }
  std::unique_ptr<Params> params(new Params());

  if (0 < args.size() &&
      !args[0].is_none()) {
    const base::Value& id_value = args[0];
    {
      auto* temp = id_value.GetIfString();
      if (!temp) {
        return std::unique_ptr<Params>();
      }
      params->id = *temp;
    }
  }
  else {
    return std::unique_ptr<Params>();
  }

  return params;
}


base::Value::List Results::Create(const EjectDeviceResultCode& result) {
  base::Value::List create_results;
  create_results.reserve(1);
  create_results.Append(system_storage::ToString(result));

  return create_results;
}
}  // namespace EjectDevice

namespace GetAvailableCapacity {

Params::Params() = default;
Params::~Params() = default;

// static
std::unique_ptr<Params> Params::Create(const base::Value::List& args) {
  if (args.size() != 1) {
    return nullptr;
  }
  std::unique_ptr<Params> params(new Params());

  if (0 < args.size() &&
      !args[0].is_none()) {
    const base::Value& id_value = args[0];
    {
      auto* temp = id_value.GetIfString();
      if (!temp) {
        return std::unique_ptr<Params>();
      }
      params->id = *temp;
    }
  }
  else {
    return std::unique_ptr<Params>();
  }

  return params;
}


base::Value::List Results::Create(const StorageAvailableCapacityInfo& info) {
  base::Value::List create_results;
  create_results.reserve(1);
  create_results.Append((info).ToValue());

  return create_results;
}
}  // namespace GetAvailableCapacity

//
// Events
//

namespace OnAttached {

const char kEventName[] = "system.storage.onAttached";

base::Value::List Create(const StorageUnitInfo& info) {
  base::Value::List create_results;
  create_results.reserve(1);
  create_results.Append((info).ToValue());

  return create_results;
}

}  // namespace OnAttached

namespace OnDetached {

const char kEventName[] = "system.storage.onDetached";

base::Value::List Create(const std::string& id) {
  base::Value::List create_results;
  create_results.reserve(1);
  create_results.Append(id);

  return create_results;
}

}  // namespace OnDetached

}  // namespace system_storage
}  // namespace api
}  // namespace extensions

